==> nextcloud-16.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_external/l10n/lv.js <==
OC.L10N.register(
    "files_external",
    {
    "External storages" : "Ārējās krātuves",
    "Personal" : "Personīgi",
    "System" : "Sistēma",
    "Grant access" : "Piešķirt pieeju",
    "Error configuring OAuth1" : "Konfigurēšanas kļūda OAuth1",
    "Please provide a valid app key and secret." : "Lūdzu, norādiet derīgu programmas atslēgu un noslēpumu.",
    "Error configuring OAuth2" : "Konfigurēšanas kļūda OAuth2",
    "Generate keys" : "Izveidot atslēgas",
    "Error generating key pair" : "Kļūda, ģenerējot atslēgu pāri",
    "All users. Type to select user or group." : "Visiem lietotājiem. Klikšķini, lai atlasītu lietotāju vai grupu.",
    "(group)" : "(grupa)",
    "Compatibility with Mac NFD encoding (slow)" : "Saderība ar Mac NFD kodēšanu (lēni)",
    "Enable encryption" : "Ieslēgt šifrēšanu",
    "Enable previews" : "Iespējot priekšskatījumu",
    "Enable sharing" : "Koplietošanas iespējošana",
    "Check for changes" : "Pārbaudīt, vai nav izmaiņu",
    "Never" : "Nekad",
    "Delete" : "Dzēst",
    "Admin defined" : "Administrators definētās",
    "Saved" : "Saglabāts",
    "Saving..." : "Saglabā...",
    "Save" : "Saglabāt",
    "Empty response from the server" : "Tukša atbilde no servera",
    "Couldn't get the information from the remote server: {code} {type}" : "Nevarējām iegūt informāciju no attālā servera: {code} {type}",
    "There was an error with message: " : "Radās kļūda ar ziņu:",
    "External mount error" : "Ārējā montēšanas kļūda",
    "external-storage" : "ārējā krātuve",
    "Username" : "Lietotājvārds",
    "Password" : "Parole",
    "Invalid mount point" : "Nederīgs montēšanas punkts",
    "%s" : "%s",
    "Access key" : "Pieejas atslēga",
    "Secret key" : "Slepenā atslēga",
    "None" : "Nav",
    "OAuth1" : "OAuth1",
    "App key" : "Programmas atslēga",
    "OAuth2" : "OAuth2",
    "Client ID" : "Klienta ID",
    "Domain" : "Domain",
    "API key" : "API atslēga",
    "Username and password" : "Lietotājvārds un parole",
    "RSA public key" : "RSA publiskā atslēga",
    "Public key" : "Publiska atslēga",
    "Amazon S3" : "Amazon S3",
    "Hostname" : "Resursa nosaukums",
    "Port" : "Ports",
    "Region" : "Reģions",
    "Enable SSL" : "Iespējot SSL",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Attālinātā apakšmape",
    "Secure https://" : "Secure https://",
    "FTP" : "FTP",
    "Host" : "Resursdators",
    "Secure ftps://" : "Secure ftps://",
    "Local" : "Lokāls",
    "Location" : "Vieta",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Root",
    "SFTP with secret key login" : "SFTP pieteikšanās ar slepeno atslēgu",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Koplietot",
    "SMB / CIFS using OC login" : "SMB / CIFS lietojot OC lietotāju",
    "OpenStack Object Storage" : "OpenStack Object krātuve",
    "Service name" : "Servisa nosaukums",
    "Name" : "Nosaukums",
    "Storage type" : "Krātuves tips",
    "Scope" : "Darbības joma",
    "Folder name" : "Mapes nosaukums",
    "External storage" : "Ārējā krātuve",
    "Authentication" : "Autentifikācija",
    "Configuration" : "Konfigurācija",
    "Available for" : "Pieejams",
    "Add storage" : "Pievienot krātuvi",
    "Advanced settings" : "Paplašināti iestatījumi",
    "Allow users to mount external storage" : "Atļaut lietotājiem uzstādīt ārējās krātuves"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");

==> nextcloud-17.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_external/l10n/lv.js <==
OC.L10N.register(
    "files_external",
    {
    "External storages" : "Ārējās krātuves",
    "Personal" : "Personīgi",
    "System" : "Sistēma",
    "Grant access" : "Piešķirt pieeju",
    "Error configuring OAuth1" : "Konfigurēšanas kļūda OAuth1",
    "Please provide a valid app key and secret." : "Lūdzu, norādiet derīgu lietotnes atslēgu un noslēpumu.",
    "Error configuring OAuth2" : "Konfigurēšanas kļūda OAuth2",
    "Generate keys" : "Izveidot atslēgas",
    "Error generating key pair" : "Kļūda, ģenerējot atslēgu pāri",
    "All users. Type to select user or group." : "Visiem lietotājiem. Klikšķini, lai atlasītu lietotāju vai grupu.",
    "(group)" : "(grupa)",
    "Compatibility with Mac NFD encoding (slow)" : "Saderība ar Mac NFD kodēšanu (lēni)",
    "Enable encryption" : "Ieslēgt šifrēšanu",
    "Enable previews" : "Iespējot priekšskatījumu",
    "Enable sharing" : "Koplietošanas iespējošana",
    "Check for changes" : "Pārbaudīt, vai nav izmaiņu",
    "Never" : "Nekad",
    "Delete" : "Dzēst",
    "Admin defined" : "Administrators definētās",
    "Saved" : "Saglabāts",
    "Saving..." : "Saglabā...",
    "Save" : "Saglabāt",
    "Empty response from the server" : "Tukša atbilde no servera",
    "Couldn't get the information from the remote server: {code} {type}" : "Nevarējām iegūt informāciju no attālā servera: {code} {type}",
    "There was an error with message: " : "Radās kļūda ar ziņu:",
    "External mount error" : "Ārējā montēšanas kļūda",
    "external-storage" : "ārējā krātuve",
    "Username" : "Lietotājvārds",
    "Password" : "Parole",
    "Invalid mount point" : "Nederīgs montēšanas punkts",
    "%s" : "%s",
    "Access key" : "Pieejas atslēga",
    "Secret key" : "Slepenā atslēga",
    "None" : "Nav",
    "OAuth1" : "OAuth1",
    "App key" : "Lietotnes atslēga",
    "OAuth2" : "OAuth2",
    "Client ID" : "Klienta ID",
    "Domain" : "Domain",
    "API key" : "API atslēga",
    "Username and password" : "Lietotājvārds un parole",
    "RSA public key" : "RSA publiskā atslēga",
    "Public key" : "Publiska atslēga",
    "Amazon S3" : "Amazon S3",
    "Hostname" : "Resursa nosaukums",
    "Port" : "Ports",
    "Region" : "Reģions",
    "Enable SSL" : "Iespējot SSL",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Attālinātā apakšmape",
    "Secure https://" : "Secure https://",
    "FTP" : "FTP",
    "Host" : "Resursdators",
    "Secure ftps://" : "Secure ftps://",
    "Local" : "Lokāls",
    "Location" : "Vieta",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Root",
    "SFTP with secret key login" : "SFTP pieteikšanās ar slepeno atslēgu",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Koplietot",
    "SMB / CIFS using OC login" : "SMB / CIFS lietojot OC lietotāju",
    "OpenStack Object Storage" : "OpenStack Object krātuve",
    "Service name" : "Servisa nosaukums",
    "Name" : "Nosaukums",
    "Storage type" : "Krātuves tips",
    "Scope" : "Darbības joma",
    "Folder name" : "Mapes nosaukums",
    "External storage" : "Ārējā krātuve",
    "Authentication" : "Autentifikācija",
    "Configuration" : "Konfigurācija",
    "Available for" : "Pieejams",
    "Add storage" : "Pievienot krātuvi",
    "Advanced settings" : "Paplašināti iestatījumi",
    "Allow users to mount external storage" : "Atļaut lietotājiem uzstādīt ārējās krātuves"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
